@@ -25,19 +25,19 @@ exporter = Exporter(globals())
 
 UND = 'UND'
 UND_ANGLE = -999.
-DIR_STRS = (
+DIR_STRS = [
     'N', 'NNE', 'NE', 'ENE',
     'E', 'ESE', 'SE', 'SSE',
     'S', 'SSW', 'SW', 'WSW',
     'W', 'WNW', 'NW', 'NNW',
     UND
-)  # note the order matters!
+]  # note the order matters!
 
 MAX_DEGREE_ANGLE = units.Quantity(360, 'degree')
 BASE_DEGREE_MULTIPLIER = units.Quantity(22.5, 'degree')
 
 DIR_DICT = {dir_str: i * BASE_DEGREE_MULTIPLIER for i, dir_str in enumerate(DIR_STRS)}
-DIR_DICT[UND] = np.nan
+DIR_DICT[UND] = units.Quantity(np.nan, 'degree')
 
 
 @exporter.export
@@ -298,12 +298,7 @@ def reduce_point_density(points, radius, priority=None):
 
     # Need to use sorted indices rather than sorting the position
     # so that the keep mask matches *original* order.
-    if priority is not None:
-        # Need to sort the locations in decreasing priority.
-        sorted_indices = np.argsort(priority)[::-1]
-    else:
-        # Take advantage of iterator nature of range here to avoid making big lists
-        sorted_indices = range(len(points))
+    sorted_indices = range(len(points)) if priority is None else np.argsort(priority)[::-1]
 
     # Keep all good points initially
     keep = np.logical_and.reduce(good_vals, axis=-1)
@@ -1773,16 +1768,15 @@ def parse_angle(input_dir):
 
     """
     if isinstance(input_dir, str):
-        # abb_dirs = abbrieviated directions
-        abb_dirs = _clean_direction([_abbrieviate_direction(input_dir)])
+        abb_dir = _clean_direction([_abbreviate_direction(input_dir)])[0]
+        return DIR_DICT[abb_dir]
     elif hasattr(input_dir, '__len__'):  # handle np.array, pd.Series, list, and array-like
         input_dir_str = ','.join(_clean_direction(input_dir, preprocess=True))
-        abb_dir_str = _abbrieviate_direction(input_dir_str)
+        abb_dir_str = _abbreviate_direction(input_dir_str)
         abb_dirs = _clean_direction(abb_dir_str.split(','))
+        return units.Quantity.from_list(itemgetter(*abb_dirs)(DIR_DICT))
     else:  # handle unrecognizable scalar
-        return np.nan
-
-    return itemgetter(*abb_dirs)(DIR_DICT)
+        return units.Quantity(np.nan, 'degree')
 
 
 def _clean_direction(dir_list, preprocess=False):
@@ -1795,7 +1789,7 @@ def _clean_direction(dir_list, preprocess=False):
                 for the_dir in dir_list]
 
 
-def _abbrieviate_direction(ext_dir_str):
+def _abbreviate_direction(ext_dir_str):
     """Convert extended (non-abbreviated) directions to abbreviation."""
     return (ext_dir_str
             .upper()
@@ -1831,6 +1825,13 @@ def angle_to_direction(input_angle, full=False, level=3):
     direction
         The directional text
 
+    Examples
+    --------
+    >>> from metpy.calc import angle_to_direction
+    >>> from metpy.units import units
+    >>> angle_to_direction(225. * units.deg)
+    'SW'
+
     """
     try:  # strip units temporarily
         origin_units = input_angle.units
@@ -1844,13 +1845,15 @@ def angle_to_direction(input_angle, full=False, level=3):
     else:
         scalar = False
 
+    np_input_angle = np.array(input_angle).astype(float)
+    origshape = np_input_angle.shape
+    ndarray = len(origshape) > 1
     # clean any numeric strings, negatives, and None does not handle strings with alphabet
-    input_angle = units.Quantity(np.array(input_angle).astype(float), origin_units)
-    input_angle[input_angle < 0] = units.Quantity(np.nan, origin_units)
+    input_angle = units.Quantity(np_input_angle, origin_units)
+    input_angle[input_angle < 0] = np.nan
 
-    # normalizer used for angles > 360 degree to normalize between 0 - 360
-    normalizer = np.array(input_angle.m / MAX_DEGREE_ANGLE.m, dtype=int)
-    norm_angles = abs(input_angle - MAX_DEGREE_ANGLE * normalizer)
+    # Normalize between 0 - 360
+    norm_angles = input_angle % MAX_DEGREE_ANGLE
 
     if level == 3:
         nskip = 1
@@ -1862,8 +1865,10 @@ def angle_to_direction(input_angle, full=False, level=3):
         err_msg = 'Level of complexity cannot be less than 1 or greater than 3!'
         raise ValueError(err_msg)
 
-    angle_dict = {i * BASE_DEGREE_MULTIPLIER.m * nskip: dir_str
-                  for i, dir_str in enumerate(DIR_STRS[::nskip])}
+    angle_dict = {
+        i * BASE_DEGREE_MULTIPLIER.m * nskip: dir_str
+        for i, dir_str in enumerate(DIR_STRS[::nskip])
+    }
     angle_dict[MAX_DEGREE_ANGLE.m] = 'N'  # handle edge case of 360.
     angle_dict[UND_ANGLE] = UND
 
@@ -1879,22 +1884,29 @@ def angle_to_direction(input_angle, full=False, level=3):
     # ['N', 'N', 'NE', 'NE', 'E', 'E', 'SE', 'SE',
     #  'S', 'S', 'SW', 'SW', 'W', 'W', 'NW', 'NW']
 
-    multiplier = np.round(
-        (norm_angles / BASE_DEGREE_MULTIPLIER / nskip) - 0.001).m
-    round_angles = (multiplier * BASE_DEGREE_MULTIPLIER.m * nskip)
+    multiplier = np.round((norm_angles / BASE_DEGREE_MULTIPLIER / nskip) - 0.001).m
+    round_angles = multiplier * BASE_DEGREE_MULTIPLIER.m * nskip
     round_angles[np.where(np.isnan(round_angles))] = UND_ANGLE
-
-    dir_str_arr = itemgetter(*round_angles)(angle_dict)  # for array
-    if not full:
-        return dir_str_arr
-
-    dir_str_arr = ','.join(dir_str_arr)
-    dir_str_arr = _unabbrieviate_direction(dir_str_arr)
-    return dir_str_arr.replace(',', ' ') if scalar else dir_str_arr.split(',')
+    if ndarray:
+        round_angles = round_angles.flatten()
+    dir_str_arr = itemgetter(*round_angles)(angle_dict)  # returns str or tuple
+    if full:
+        dir_str_arr = ','.join(dir_str_arr)
+        dir_str_arr = _unabbreviate_direction(dir_str_arr)
+        dir_str_arr = dir_str_arr.split(',')
+        if scalar:
+            return dir_str_arr[0]
+        else:
+            return np.array(dir_str_arr).reshape(origshape)
+    else:
+        if scalar:
+            return dir_str_arr
+        else:
+            return np.array(dir_str_arr).reshape(origshape)
 
 
-def _unabbrieviate_direction(abb_dir_str):
-    """Convert abbrieviated directions to non-abbrieviated direction."""
+def _unabbreviate_direction(abb_dir_str):
+    """Convert abbreviated directions to non-abbreviated direction."""
     return (abb_dir_str
             .upper()
             .replace(UND, 'Undefined ')
