@@ -5,6 +5,7 @@
 
 from datetime import datetime, timedelta
 from io import BytesIO
+from unittest.mock import patch, PropertyMock
 import warnings
 
 import matplotlib.pyplot as plt
@@ -20,11 +21,11 @@ from metpy.io import GiniFile
 from metpy.io.metar import parse_metar_file
 from metpy.plots import (ArrowPlot, BarbPlot, ContourPlot, FilledContourPlot, ImagePlot,
                          MapPanel, PanelContainer, PlotGeometry, PlotObs, RasterPlot)
-from metpy.testing import needs_cartopy
+from metpy.testing import needs_cartopy, version_check
 from metpy.units import units
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.005)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.02)
 @needs_cartopy
 def test_declarative_image():
     """Test making an image plot."""
@@ -32,7 +33,7 @@ def test_declarative_image():
 
     img = ImagePlot()
     img.data = data.metpy.parse_cf('IR')
-    img.colormap = 'Greys_r'
+    img.mpl_args = {'cmap': 'Greys_r'}
 
     panel = MapPanel()
     panel.title = 'Test'
@@ -91,7 +92,7 @@ def test_declarative_four_dims_error():
         pc.draw()
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.09)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.096)
 @needs_cartopy
 def test_declarative_contour():
     """Test making a contour plot."""
@@ -119,7 +120,7 @@ def test_declarative_contour():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=False, tolerance=0.091)
+@pytest.mark.mpl_image_compare(remove_text=False, tolerance=0.094)
 @needs_cartopy
 def test_declarative_titles():
     """Test making a contour plot with multiple titles."""
@@ -150,7 +151,7 @@ def test_declarative_titles():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.066)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.101)
 @needs_cartopy
 def test_declarative_smooth_contour():
     """Test making a contour plot using smooth_contour."""
@@ -179,12 +180,12 @@ def test_declarative_smooth_contour():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.09)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.121)
 @needs_cartopy
 def test_declarative_smooth_contour_calculation():
     """Test making a contour plot using smooth_contour."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
-    data = data.metpy.parse_cf()
+    data = data.metpy.parse_cf().metpy.assign_latitude_longitude()
 
     data['wind_speed'] = wind_speed(data['u_wind'], data['v_wind'])
 
@@ -221,7 +222,7 @@ def test_declarative_smooth_contour_calculation():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.01)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.034)
 @needs_cartopy
 def test_declarative_smooth_contour_order():
     """Test making a contour plot using smooth_contour with tuple."""
@@ -250,7 +251,7 @@ def test_declarative_smooth_contour_order():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.058)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.063)
 @needs_cartopy
 def test_declarative_figsize():
     """Test having an all float figsize."""
@@ -278,7 +279,7 @@ def test_declarative_figsize():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.029)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.039)
 @needs_cartopy
 def test_declarative_smooth_field():
     """Test the smoothing of the field with smooth_field trait."""
@@ -307,7 +308,7 @@ def test_declarative_smooth_field():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.708)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.828)
 @needs_cartopy
 def test_declarative_contour_cam():
     """Test making a contour plot with CAM data."""
@@ -334,7 +335,9 @@ def test_declarative_contour_cam():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.03)
+@pytest.mark.mpl_image_compare(
+    remove_text=True,
+    tolerance=3.71 if version_check('matplotlib<3.8') else 0.74)
 @needs_cartopy
 def test_declarative_contour_options():
     """Test making a contour plot."""
@@ -364,10 +367,10 @@ def test_declarative_contour_options():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.08)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.085)
 @needs_cartopy
 def test_declarative_layers_plot_options():
-    """Test making a contour plot."""
+    """Test declarative layer options of edgecolor and linewidth."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
 
     contour = ContourPlot()
@@ -376,7 +379,7 @@ def test_declarative_layers_plot_options():
     contour.level = 700 * units.hPa
     contour.contours = 5
     contour.linewidth = 1
-    contour.linecolor = 'grey'
+    contour.mpl_args = {'colors': 'grey'}
 
     panel = MapPanel()
     panel.area = 'us'
@@ -394,7 +397,42 @@ def test_declarative_layers_plot_options():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.0152)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.021)
+@needs_cartopy
+def test_declarative_additional_layers_plot_options():
+    """Test additional declarative layer options of linestyle, zorder, and alpha."""
+    data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
+
+    contour = ContourPlot()
+    contour.data = data
+    contour.field = 'Temperature'
+    contour.level = 700 * units.hPa
+    contour.contours = 5
+    contour.linewidth = 1
+    contour.linecolor = 'grey'
+
+    panel = MapPanel()
+    panel.area = 'us'
+    panel.projection = 'lcc'
+    panel.layers = ['coastline', 'usstates', 'borders', 'lakes', 'rivers']
+    panel.layers_edgecolor = ['blue', 'red', 'black', None, 'water']
+    panel.layers_linewidth = [0.75, 0.75, 1, 1, 1]
+    panel.layers_linestyle = ['solid', 'dotted', 'dashed', 'dotted']
+    panel.layers_alpha = [1, .5, .75, 1]
+    panel.layers_zorder = [1, 1, 1, -1, -1]
+    panel.plots = [contour]
+
+    pc = PanelContainer()
+    pc.size = (8, 8)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
+@pytest.mark.mpl_image_compare(
+    remove_text=True,
+    tolerance=2.74 if version_check('matplotlib<3.8') else 1.91)
 @needs_cartopy
 def test_declarative_contour_convert_units():
     """Test making a contour plot."""
@@ -424,7 +462,7 @@ def test_declarative_contour_convert_units():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.246)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.276)
 @needs_cartopy
 def test_declarative_events():
     """Test that resetting traitlets properly propagates."""
@@ -468,7 +506,7 @@ def test_declarative_events():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.009)
 @needs_cartopy
 def test_declarative_raster_events():
     """Test that resetting traitlets properly propagates in RasterPlot()."""
@@ -532,6 +570,8 @@ def test_ndim_error_scalar(cfeature):
     with pytest.raises(ValueError):
         pc.draw()
 
+    plt.close(pc.figure)
+
 
 def test_ndim_error_vector(cfeature):
     """Make sure we get a useful error when the field is not set."""
@@ -553,6 +593,8 @@ def test_ndim_error_vector(cfeature):
     with pytest.raises(ValueError):
         pc.draw()
 
+    plt.close(pc.figure)
+
 
 def test_no_field_error_barbs():
     """Make sure we get a useful error when the field is not set."""
@@ -566,7 +608,7 @@ def test_no_field_error_barbs():
         barbs.draw()
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.377)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.381)
 def test_projection_object(ccrs, cfeature):
     """Test that we can pass a custom map projection."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
@@ -589,8 +631,9 @@ def test_projection_object(ccrs, cfeature):
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0)
-def test_colorfill(cfeature):
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.009)
+@needs_cartopy
+def test_colorfill():
     """Test that we can use ContourFillPlot."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
 
@@ -614,7 +657,7 @@ def test_colorfill(cfeature):
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.0062)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.02)
 def test_colorfill_with_image_range(cfeature):
     """Test that we can use ContourFillPlot with image_range bounds."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
@@ -641,7 +684,7 @@ def test_colorfill_with_image_range(cfeature):
 
 
 @pytest.mark.mpl_image_compare(
-    remove_text=True, tolerance=0.0062, filename='test_colorfill_with_image_range.png'
+    remove_text=True, tolerance=0.02, filename='test_colorfill_with_image_range.png'
 )
 def test_colorfill_with_normalize_instance_image_range(cfeature):
     """Test that we can use ContourFillPlot with image_range bounds."""
@@ -668,8 +711,9 @@ def test_colorfill_with_normalize_instance_image_range(cfeature):
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.)
-def test_colorfill_horiz_colorbar(cfeature):
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.02)
+@needs_cartopy
+def test_colorfill_horiz_colorbar():
     """Test that we can use ContourFillPlot with a horizontal colorbar."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
 
@@ -693,7 +737,32 @@ def test_colorfill_horiz_colorbar(cfeature):
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.0062)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.02)
+def test_colorbar_kwargs(cfeature):
+    """Test that we can use ContourFillPlot with specifying colorbar kwargs."""
+    data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
+
+    contour = FilledContourPlot()
+    contour.data = data
+    contour.level = 700 * units.hPa
+    contour.field = 'Temperature'
+    contour.colormap = 'coolwarm'
+    contour.colorbar = {'orientation': 'horizontal', 'aspect': 60, 'pad': 0.05}
+
+    panel = MapPanel()
+    panel.area = (-110, -60, 25, 55)
+    panel.layers = []
+    panel.plots = [contour]
+
+    pc = PanelContainer()
+    pc.panel = panel
+    pc.size = (8, 8)
+    pc.draw()
+
+    return pc.figure
+
+
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.02)
 def test_colorfill_no_colorbar(cfeature):
     """Test that we can use ContourFillPlot with no colorbar."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
@@ -771,7 +840,7 @@ def test_latlon():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.292)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.393)
 @needs_cartopy
 def test_declarative_barb_options():
     """Test making a contour plot."""
@@ -783,7 +852,8 @@ def test_declarative_barb_options():
     barb.field = ['u_wind', 'v_wind']
     barb.skip = (10, 10)
     barb.color = 'blue'
-    barb.pivot = 'tip'
+    barb.pivot = 'middle'
+    barb.mpl_args = {'pivot': 'tip'}
     barb.barblength = 6.5
 
     panel = MapPanel()
@@ -812,7 +882,8 @@ def test_declarative_arrowplot():
     arrows.field = ['u_wind', 'v_wind']
     arrows.skip = (10, 10)
     arrows.color = 'blue'
-    arrows.pivot = 'mid'
+    arrows.pivot = 'tip'
+    arrows.mpl_args = {'pivot': 'mid'}
     arrows.arrowscale = 1000
 
     panel = MapPanel()
@@ -891,7 +962,7 @@ def test_declarative_arrow_changes():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.491)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.891)
 @needs_cartopy
 def test_declarative_barb_earth_relative():
     """Test making a contour plot."""
@@ -969,7 +1040,7 @@ def test_declarative_overlay_projections():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.021)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.047)
 @needs_cartopy
 def test_declarative_gridded_scale():
     """Test making a contour plot."""
@@ -1086,7 +1157,7 @@ def test_declarative_barb_scale():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.667)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.668)
 @needs_cartopy
 def test_declarative_barb_gfs_knots():
     """Test making a contour plot."""
@@ -1128,6 +1199,14 @@ def sample_obs():
                         columns=['time', 'stid', 'pressure', 'temperature', 'dewpoint'])
 
 
+@pytest.fixture()
+def pandas_sfc():
+    """Open sample pandas data."""
+    df = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False))
+    df['valid'] = pd.to_datetime(df['valid'], format='%Y-%m-%d %H:%M:%S')
+    return df
+
+
 def test_plotobs_subset_default_nolevel(sample_obs):
     """Test PlotObs subsetting with minimal config."""
     obs = PlotObs()
@@ -1217,16 +1296,17 @@ def test_plotobs_subset_time_window_level(sample_obs):
     pd.testing.assert_frame_equal(obs.obsdata, truth)
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0)
-def test_plotobs_units_with_formatter(ccrs):
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.016)
+def test_plotobs_units_with_formatter(ccrs, pandas_sfc):
     """Test using PlotObs with a field that both has units and a custom formatter."""
-    df = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
-                     infer_datetime_format=True, parse_dates=['valid'])
-    df.units = {'alti': 'inHg'}
+    # Catch warning from Pandas due to setting units
+    with warnings.catch_warnings():
+        warnings.simplefilter('ignore', UserWarning)
+        pandas_sfc.units = {'alti': 'inHg'}
 
     # Plot desired data
     obs = PlotObs()
-    obs.data = df
+    obs.data = pandas_sfc
     obs.time = datetime(1993, 3, 12, 12)
     obs.time_window = timedelta(minutes=15)
     obs.level = None
@@ -1254,13 +1334,10 @@ def test_plotobs_units_with_formatter(ccrs):
 
 
 @pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.025)
-def test_declarative_sfc_obs(ccrs):
+def test_declarative_sfc_obs(ccrs, pandas_sfc):
     """Test making a surface observation plot."""
-    data = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
-                       infer_datetime_format=True, parse_dates=['valid'])
-
     obs = PlotObs()
-    obs.data = data
+    obs.data = pandas_sfc
     obs.time = datetime(1993, 3, 12, 12)
     obs.time_window = timedelta(minutes=15)
     obs.level = None
@@ -1285,15 +1362,42 @@ def test_declarative_sfc_obs(ccrs):
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.)
-@needs_cartopy
-def test_declarative_sfc_text():
-    """Test making a surface observation plot with text."""
-    data = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
-                       infer_datetime_format=True, parse_dates=['valid'])
-
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.025)
+def test_declarative_sfc_obs_args(ccrs, pandas_sfc):
+    """Test making a surface observation plot with mpl arguments."""
     obs = PlotObs()
-    obs.data = data
+    obs.data = pandas_sfc
+    obs.time = datetime(1993, 3, 12, 12)
+    obs.time_window = timedelta(minutes=15)
+    obs.level = None
+    obs.fields = ['tmpf']
+    obs.colors = ['black']
+    obs.mpl_args = {'fontsize': 12}
+
+    # Panel for plot with Map features
+    panel = MapPanel()
+    panel.layout = (1, 1, 1)
+    panel.projection = ccrs.PlateCarree()
+    panel.area = 'in'
+    panel.layers = ['states']
+    panel.plots = [obs]
+
+    # Bringing it all together
+    pc = PanelContainer()
+    pc.size = (10, 10)
+    pc.panels = [panel]
+
+    pc.draw()
+
+    return pc.figure
+
+
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.016)
+@needs_cartopy
+def test_declarative_sfc_text(pandas_sfc):
+    """Test making a surface observation plot with text."""
+    obs = PlotObs()
+    obs.data = pandas_sfc
     obs.time = datetime(1993, 3, 12, 12)
     obs.time_window = timedelta(minutes=15)
     obs.level = None
@@ -1320,13 +1424,10 @@ def test_declarative_sfc_text():
 
 
 @pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.025)
-def test_declarative_sfc_obs_changes(ccrs):
+def test_declarative_sfc_obs_changes(ccrs, pandas_sfc):
     """Test making a surface observation plot, changing the field."""
-    data = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
-                       infer_datetime_format=True, parse_dates=['valid'])
-
     obs = PlotObs()
-    obs.data = data
+    obs.data = pandas_sfc
     obs.time = datetime(1993, 3, 12, 12)
     obs.level = None
     obs.fields = ['tmpf']
@@ -1356,13 +1457,10 @@ def test_declarative_sfc_obs_changes(ccrs):
 
 
 @pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.171)
-def test_declarative_colored_barbs(ccrs):
+def test_declarative_colored_barbs(ccrs, pandas_sfc):
     """Test making a surface plot with a colored barb (gh-1274)."""
-    data = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
-                       infer_datetime_format=True, parse_dates=['valid'])
-
     obs = PlotObs()
-    obs.data = data
+    obs.data = pandas_sfc
     obs.time = datetime(1993, 3, 12, 13)
     obs.level = None
     obs.vector_field = ('uwind', 'vwind')
@@ -1388,13 +1486,10 @@ def test_declarative_colored_barbs(ccrs):
 
 
 @pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.305)
-def test_declarative_sfc_obs_full(ccrs):
+def test_declarative_sfc_obs_full(ccrs, pandas_sfc):
     """Test making a full surface observation plot."""
-    data = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
-                       infer_datetime_format=True, parse_dates=['valid'])
-
     obs = PlotObs()
-    obs.data = data
+    obs.data = pandas_sfc
     obs.time = datetime(1993, 3, 12, 13)
     obs.time_window = timedelta(minutes=15)
     obs.level = None
@@ -1425,7 +1520,7 @@ def test_declarative_sfc_obs_full(ccrs):
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.355)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.522)
 @needs_cartopy
 def test_declarative_upa_obs():
     """Test making a full upperair observation plot."""
@@ -1462,7 +1557,7 @@ def test_declarative_upa_obs():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.473)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.518)
 @needs_cartopy
 def test_declarative_upa_obs_convert_barb_units():
     """Test making a full upperair observation plot with barbs converting units."""
@@ -1505,14 +1600,12 @@ def test_declarative_upa_obs_convert_barb_units():
     return pc.figure
 
 
-def test_attribute_error_time(ccrs):
+def test_attribute_error_time(ccrs, pandas_sfc):
     """Make sure we get a useful error when the time variable is not found."""
-    data = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
-                       infer_datetime_format=True, parse_dates=['valid'])
-    data.rename(columns={'valid': 'vtime'}, inplace=True)
+    pandas_sfc.rename(columns={'valid': 'vtime'}, inplace=True)
 
     obs = PlotObs()
-    obs.data = data
+    obs.data = pandas_sfc
     obs.time = datetime(1993, 3, 12, 12)
     obs.level = None
     obs.fields = ['tmpf']
@@ -1535,15 +1628,15 @@ def test_attribute_error_time(ccrs):
     with pytest.raises(AttributeError):
         pc.draw()
 
+    plt.close(pc.figure)
 
-def test_attribute_error_station(ccrs):
+
+def test_attribute_error_station(ccrs, pandas_sfc):
     """Make sure we get a useful error when the station variable is not found."""
-    data = pd.read_csv(get_test_data('SFC_obs.csv', as_file_obj=False),
-                       infer_datetime_format=True, parse_dates=['valid'])
-    data.rename(columns={'station': 'location'}, inplace=True)
+    pandas_sfc.rename(columns={'station': 'location'}, inplace=True)
 
     obs = PlotObs()
-    obs.data = data
+    obs.data = pandas_sfc
     obs.time = datetime(1993, 3, 12, 12)
     obs.level = None
     obs.fields = ['tmpf']
@@ -1566,6 +1659,8 @@ def test_attribute_error_station(ccrs):
     with pytest.raises(AttributeError):
         pc.draw()
 
+    plt.close(pc.figure)
+
 
 @pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.024)
 def test_declarative_sfc_obs_change_units(ccrs):
@@ -1760,7 +1855,7 @@ def test_declarative_contour_label_fontsize():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.02)
 @needs_cartopy
 def test_declarative_raster():
     """Test making a raster plot."""
@@ -1786,6 +1881,33 @@ def test_declarative_raster():
     return pc.figure
 
 
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.02)
+@needs_cartopy
+def test_declarative_raster_options():
+    """Test making a raster plot."""
+    data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
+
+    raster = RasterPlot()
+    raster.data = data
+    raster.colormap = 'viridis'
+    raster.field = 'Temperature'
+    raster.level = 700 * units.hPa
+    raster.mpl_args = {'alpha': 1, 'cmap': 'coolwarm'}
+
+    panel = MapPanel()
+    panel.area = 'us'
+    panel.projection = 'lcc'
+    panel.layers = ['coastline']
+    panel.plots = [raster]
+
+    pc = PanelContainer()
+    pc.size = (8.0, 8)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
 @pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.607)
 @needs_cartopy
 def test_declarative_region_modifier_zoom_in():
@@ -1810,7 +1932,7 @@ def test_declarative_region_modifier_zoom_in():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.332)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.338)
 @needs_cartopy
 def test_declarative_region_modifier_zoom_out():
     """Test that '-' suffix on area string properly expands extent of map."""
@@ -1857,6 +1979,7 @@ def test_save():
     pc = PanelContainer()
     fobj = BytesIO()
     pc.save(fobj, format='png')
+    plt.close(pc.figure)
 
     fobj.seek(0)
 
@@ -1864,14 +1987,14 @@ def test_save():
     assert fobj.read()
 
 
-def test_show(set_agg_backend):
+def test_show():
     """Test that show works properly."""
     pc = PanelContainer()
-
-    # Matplotlib warns when using show with Agg
-    with warnings.catch_warnings():
-        warnings.simplefilter('ignore', UserWarning)
+    with patch.object(plt, 'show', new_callable=PropertyMock) as show:
         pc.show()
+        show.assert_called()
+
+    plt.close(pc.figure)
 
 
 @needs_cartopy
@@ -1913,6 +2036,7 @@ def test_copy():
     copied_obj = obj.copy()
     assert obj is not copied_obj
     assert obj.size == copied_obj.size
+    plt.close(obj.figure)
 
     # Copies of plots in MapPanels should not point to same location in memory
     obj = MapPanel()
@@ -1946,6 +2070,7 @@ def test_declarative_plot_geometry_polygons():
     geo = PlotGeometry()
     geo.geometry = [slgt_risk_polygon, enh_risk_polygon]
     geo.stroke = ['#DDAA00', '#FF6600']
+    geo.stroke_width = [1]
     geo.fill = None
     geo.labels = ['SLGT', 'ENH']
     geo.label_facecolor = ['#FFE066', '#FFA366']
@@ -1990,6 +2115,7 @@ def test_declarative_plot_geometry_lines(ccrs):
     geo.stroke = 'green'
     geo.labels = ['Irma', '+/- 0.25 deg latitude']
     geo.label_facecolor = None
+    geo.mpl_args = {'linewidth': 1}
 
     # Place plot in a panel and container
     panel = MapPanel()
@@ -2007,6 +2133,42 @@ def test_declarative_plot_geometry_lines(ccrs):
     return pc.figure
 
 
+@pytest.mark.mpl_image_compare(remove_text=False, tolerance=0.013)
+def test_declarative_plot_geometry_fills(ccrs):
+    """Test that `PlotGeometry` correctly plots MultiLineString and LineString objects."""
+    from shapely.geometry import Polygon
+
+    # MultiPolygons and Polygons to plot
+    mdt_risk_polygon = Polygon(
+        [(-87.07, 31.68), (-88.65, 30.96), (-91.83, 30.52), (-92.83, 30.82), (-93.18, 31.77),
+         (-92.65, 33.31), (-92.64, 35.22), (-91.74, 36.16), (-88.84, 35.53), (-86.13, 34.5),
+         (-85.45, 33.01), (-86, 32.05), (-87.07, 31.68)])
+    high_risk_polygon = Polygon(
+        [(-91.88, 32.99), (-89.82, 34.4), (-88.19, 34.21), (-87.72, 33.46), (-88.23, 32.48),
+         (-90.53, 32), (-91.74, 32.07), (-91.88, 32.99)])
+
+    # Plot geometry, set colors and labels
+    geo = PlotGeometry()
+    geo.geometry = [mdt_risk_polygon, high_risk_polygon]
+    geo.fill = ['#E06666', '#EE99EE']
+    geo.stroke = ['#E06666', '#EE99EE']
+    geo.labels = None
+
+    # Place plot in a panel and container
+    panel = MapPanel()
+    panel.area = [-120, -75, 25, 50]
+    panel.projection = 'lcc'
+    panel.title = ' '
+    panel.plots = [geo]
+
+    pc = PanelContainer()
+    pc.size = (12, 12)
+    pc.panels = [panel]
+    pc.draw()
+
+    return pc.figure
+
+
 @pytest.mark.mpl_image_compare(remove_text=False, tolerance=1.900)
 def test_declarative_plot_geometry_points(ccrs):
     """Test that `PlotGeometry` correctly plots Point and MultiPoint objects."""
