@@ -11,10 +11,9 @@ import numpy as np
 import pytest
 
 from metpy.plots import Hodograph, SkewT
+from metpy.testing import autoclose_figure, version_check
 from metpy.units import units
 
-MPL_VERSION = matplotlib.__version__[:5]
-
 
 @pytest.mark.mpl_image_compare(remove_text=True, style='default', tolerance=0.069)
 def test_skewt_api():
@@ -86,7 +85,7 @@ def test_skewt_default_aspect_empty():
 @pytest.mark.mpl_image_compare(tolerance=0., remove_text=True, style='default')
 def test_skewt_mixing_line_args():
     """Test plot_mixing_lines accepting kwargs for mixing ratio and pressure levels."""
-    # Explicitly pass default values as kwargs the, should recreate NWS SkewT PDF as above
+    # Explicitly pass default values as kwargs, should recreate NWS SkewT PDF as above
     fig = plt.figure(figsize=(12, 9))
     skew = SkewT(fig, rotation=43)
     mlines = np.array([0.0004, 0.001, 0.002, 0.004, 0.007, 0.01, 0.016, 0.024, 0.032])
@@ -127,7 +126,8 @@ def test_skewt_with_grid_enabled():
     """Test using SkewT when gridlines are already enabled (#271)."""
     with plt.rc_context(rc={'axes.grid': True}):
         # Also tests when we don't pass in Figure
-        SkewT(aspect='auto')
+        s = SkewT(aspect='auto')
+        plt.close(s.ax.figure)
 
 
 @pytest.mark.mpl_image_compare(tolerance=0., remove_text=True, style='default')
@@ -140,8 +140,8 @@ def test_skewt_arbitrary_rect():
 
 def test_skewt_subplot_rect_conflict():
     """Test the subplot/rect conflict failure."""
-    with pytest.raises(ValueError):
-        SkewT(rect=(0.15, 0.35, 0.8, 0.3), subplot=(1, 1, 1))
+    with pytest.raises(ValueError), autoclose_figure(figsize=(7, 7)) as fig:
+        SkewT(fig, rect=(0.15, 0.35, 0.8, 0.3), subplot=(1, 1, 1))
 
 
 @pytest.mark.mpl_image_compare(tolerance=0.0198, remove_text=True, style='default')
@@ -156,8 +156,10 @@ def test_skewt_units():
     skew.ax.axvline(-10, color='orange')
 
     # On Matplotlib <= 3.6, ax[hv]line() doesn't trigger unit labels
-    assert skew.ax.get_xlabel() == ('degree_Celsius' if MPL_VERSION == '3.7.0' else '')
-    assert skew.ax.get_ylabel() == ('hectopascal' if MPL_VERSION == '3.7.0' else '')
+    assert skew.ax.get_xlabel() == (
+        'degree_Celsius' if version_check('matplotlib==3.7.0') else '')
+    assert skew.ax.get_ylabel() == (
+        'hectopascal' if version_check('matplotlib==3.7.0') else '')
 
     # Clear them for the image test
     skew.ax.set_xlabel('')
@@ -261,12 +263,12 @@ def test_skewt_shade_area(test_profile):
 def test_skewt_shade_area_invalid(test_profile):
     """Test shading areas on a SkewT plot."""
     p, t, _, tp = test_profile
-    fig = plt.figure(figsize=(9, 9))
-    skew = SkewT(fig, aspect='auto')
-    skew.plot(p, t, 'r')
-    skew.plot(p, tp, 'k')
-    with pytest.raises(ValueError):
-        skew.shade_area(p, t, tp, which='positve')
+    with autoclose_figure(figsize=(9, 9)) as fig:
+        skew = SkewT(fig, aspect='auto')
+        skew.plot(p, t, 'r')
+        skew.plot(p, tp, 'k')
+        with pytest.raises(ValueError):
+            skew.shade_area(p, t, tp, which='positve')
 
 
 @pytest.mark.mpl_image_compare(tolerance=0.033, remove_text=True, style='default')
@@ -319,8 +321,8 @@ def test_hodograph_api():
     return fig
 
 
-@pytest.mark.mpl_image_compare(remove_text=True,
-                               tolerance=0.6 if MPL_VERSION.startswith('3.3') else 0.)
+@pytest.mark.mpl_image_compare(
+    remove_text=True, tolerance=0.6 if version_check('matplotlib==3.5') else 0.)
 def test_hodograph_units():
     """Test passing quantities to Hodograph."""
     fig = plt.figure(figsize=(9, 9))
@@ -355,7 +357,8 @@ def test_hodograph_masked_array():
 
 def test_hodograph_alone():
     """Test to create Hodograph without specifying axes."""
-    Hodograph()
+    h = Hodograph()
+    plt.close(h.ax.figure)
 
 
 @pytest.mark.mpl_image_compare(tolerance=0, remove_text=True)
@@ -429,10 +432,10 @@ def test_skewt_barb_unit_conversion_exception(u, v):
     """Test that an error is raised if unit conversion is requested on plain arrays."""
     p_wind = np.array([500]) * units.hPa
 
-    fig = plt.figure(figsize=(9, 9))
-    skew = SkewT(fig, aspect='auto')
-    with pytest.raises(ValueError):
-        skew.plot_barbs(p_wind, u, v, plot_units='knots')
+    with autoclose_figure(figsize=(9, 9)) as fig:
+        skew = SkewT(fig, aspect='auto')
+        with pytest.raises(ValueError):
+            skew.plot_barbs(p_wind, u, v, plot_units='knots')
 
 
 @pytest.mark.mpl_image_compare(tolerance=0, remove_text=True)
@@ -570,6 +573,6 @@ def test_hodograph_wind_vectors():
 
 def test_hodograph_range_with_units():
     """Tests making a hodograph with a range with units."""
-    fig = plt.figure(figsize=(6, 6))
-    ax = fig.add_subplot(1, 1, 1)
-    Hodograph(ax, component_range=60. * units.knots)
+    with autoclose_figure(figsize=(6, 6)) as fig:
+        ax = fig.add_subplot(1, 1, 1)
+        Hodograph(ax, component_range=60. * units.knots)
